@@ -2,16 +2,6 @@ from CFNetwork import *
 from PyObjCTools.TestSupport import *
 from Foundation import NSString
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-except NameError:
-    long = int
-
 class TestCFFTPStream (TestCase):
 
     def testTypes(self):
@@ -102,10 +92,5 @@ class TestCFFTPStream (TestCase):
         v = CFHTTPAuthenticationRequiresAccountDomain(ref)
         self.assertIsInstance(v, bool)
 
-
-
-
-
-
 if __name__ == "__main__":
     main()
